Jura is a family of sans-serif fonts in the Eurostile vein. It was originally inspired by some work I was doing for the FreeFont project in designing a Kayah Li range for FreeMono. I wanted to create a Roman alphabet using the same kinds of strokes and curves as the Kayah Li glyphs, and thus Jura was born. It has been expanded to include glyphs for the Cyrillic and Greek alphabets as well.

The original Kayah Li glyphs have been included in this font. (Note that glyphs for writing mainstream Burmese are not and never have been a part of this font.)

Jura is available in four weights: Light, Book, Medium, and DemiBold. Jura is also available as a variable font.

The Jura family has an unfortunate name clash with Ed Merritt’s Jura serif font.